@@ -2,11 +2,8 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::Run::Role::Runner;
-BEGIN {
-  $Dist::Zilla::Plugin::Run::Role::Runner::AUTHORITY = 'cpan:GETTY';
-}
 # ABSTRACT: Role for the packages of Dist::Zilla::Plugin::Run
-$Dist::Zilla::Plugin::Run::Role::Runner::VERSION = '0.023';
+$Dist::Zilla::Plugin::Run::Role::Runner::VERSION = '0.027';
 use Moose::Role;
 use namespace::autoclean;
 use File::Spec (); # core
@@ -66,6 +63,12 @@ has run_no_release => (
     default => sub { [] },
 );
 
+has eval => (
+    is => 'ro',
+    isa  => 'ArrayRef[Str]',
+    default => sub { [] },
+);
+
 around dump_config => sub
 {
     my ($orig, $self) = @_;
@@ -77,7 +80,7 @@ around dump_config => sub
             ? ( $_ => ( $self->censor_commands ? 'REDACTED' : $self->$_ ) )
             : ()
         }
-        qw(run run_if_trial run_no_trial run_if_release run_no_release),
+        qw(run run_if_trial run_no_trial run_if_release run_no_release eval),
     };
 
     return $config;
@@ -139,6 +142,14 @@ sub call_script {
         }
     }
 
+    if (my @code = @{ $self->eval }) {
+        my $code = join "\n", @code;
+        $self->log("evaluating: $code");
+
+        my $sub = sub { eval $code };
+        $sub->($self);
+        $self->log('evaluation died: ' . $@) if $@;
+    }
 }
 
 sub run_cmd {
@@ -171,7 +182,7 @@ around mvp_multivalue_args => sub {
 
     my @res = $self->$original();
 
-    push @res, qw( run run_no_trial run_if_trial run_if_release run_no_release );
+    push @res, qw( run run_no_trial run_if_trial run_if_release run_no_release eval );
 
     @res;
 };
@@ -210,6 +221,7 @@ sub build_formatter {
     # available during build, not mint
     unless( $params->{minting} ){
         $codes->{v} = sub { $self->zilla->version };
+        $codes->{t} = sub { $self->zilla->is_trial ? '-TRIAL' : '' };
     }
 
     # positional replace (backward compatible)
@@ -226,7 +238,7 @@ sub build_formatter {
 }
 
 sub current_perl_path {
-    # see perlvar $^X
+    # see perlvar $^X for why we don't just use that here
     my $perl = $Config::Config{perlpath};
     if ($^O ne 'VMS') {
         $perl .= $Config::Config{_exe}
@@ -256,7 +268,7 @@ Dist::Zilla::Plugin::Run::Role::Runner - Role for the packages of Dist::Zilla::P
 
 =head1 VERSION
 
-version 0.023
+version 0.027
 
 =head1 DESCRIPTION
 
